@@ -75,8 +75,7 @@ static void writeTestFilesToArchive(KArchive *archive)
     QVERIFY(archive->writeFile("my/dir/test3", "I do not speak German\nDavid.", 0100644, "dfaure", "hackers"));
 
     // Now a medium file : 100 null bytes
-    char medium[SIZE1];
-    memset(medium, 0, SIZE1);
+    char medium[SIZE1] = {0};
     QVERIFY(archive->writeFile("mediumfile", QByteArray(medium, SIZE1)));
     // Another one, with an absolute path
     QVERIFY(archive->writeFile("/dir/subdir/mediumfile2", QByteArray(medium, SIZE1)));
@@ -140,7 +139,7 @@ static QStringList recursiveListEntries(const KArchiveDirectory *dir, const QStr
     QStringList ret;
     QStringList l = dir->entries();
     l.sort();
-    for (const QString &it : qAsConst(l)) {
+    for (const QString &it : std::as_const(l)) {
         const KArchiveEntry *entry = dir->entry(it);
 
         QString descr;
@@ -181,6 +180,8 @@ static void testFileData(KArchive *archive)
     const KArchiveDirectory *dir = archive->directory();
 
     const KArchiveFile *f = dir->file(QStringLiteral("z/test3"));
+    QVERIFY(f);
+
     QByteArray arr(f->data());
     QCOMPARE(arr.size(), 13);
     QCOMPARE(arr, QByteArray("Noch so einer"));
@@ -672,7 +673,8 @@ void KArchiveTest::testTarMaxLength()
     // Also exceed 512 byte block size limit to see how well the ././@LongLink
     // implementation fares
     for (int i = 98; i < 514; i++) {
-        QString str, num;
+        QString str;
+        QString num;
         str.fill('a', i - 10);
         num.setNum(i);
         num = num.rightJustified(10, '0');
@@ -1054,7 +1056,8 @@ void KArchiveTest::testZipMaxLength()
     // Similar to testTarMaxLength just to make sure, but of course zip doesn't have
     // those limitations in the first place.
     for (int i = 98; i < 514; i++) {
-        QString str, num;
+        QString str;
+        QString num;
         str.fill('a', i - 10);
         num.setNum(i);
         num = num.rightJustified(10, '0');
@@ -1158,6 +1161,9 @@ void KArchiveTest::testZipAddLocalDirectory()
     const QString file1 = QStringLiteral("file1");
     QVERIFY(writeFile(dirName, file1, file1Data));
 
+    const QString emptyDir = QStringLiteral("emptyDir");
+    QDir(dirName).mkdir(emptyDir);
+
     {
         KZip zip(s_zipFileName);
 
@@ -1175,8 +1181,11 @@ void KArchiveTest::testZipAddLocalDirectory()
 
         const KArchiveEntry *e = dir->entry(file1);
         QVERIFY(e && e->isFile());
-        const KArchiveFile *f = (KArchiveFile *)e;
+        const KArchiveFile *f = static_cast<const KArchiveFile *>(e);
         QCOMPARE(f->data(), file1Data);
+
+        const KArchiveEntry *empty = dir->entry(emptyDir);
+        QVERIFY(empty && empty->isDirectory());
     }
 }
 
@@ -1279,6 +1288,28 @@ void KArchiveTest::testZipDuplicateNames()
     QVERIFY2(metaInfCount == 1, "Archive root directory contains duplicates");
 }
 
+void KArchiveTest::testZip64()
+{
+    QString fileName = QFINDTESTDATA("data/zip64.pkpass");
+    QVERIFY(!fileName.isEmpty());
+
+    KZip zip(fileName);
+    QVERIFY(zip.open(QIODevice::ReadOnly));
+
+    // NOTE the actual content of this file has been wiped, we can only verify the file meta data here
+    QCOMPARE(zip.directory()->entries().size(), 7);
+    auto entry = static_cast<const KZipFileEntry *>(zip.directory()->entry(QStringLiteral("manifest.json")));
+    QVERIFY(entry);
+    QCOMPARE(entry->size(), 305);
+    QCOMPARE(entry->compressedSize(), 194);
+    QCOMPARE(entry->position(), 21417);
+    entry = static_cast<const KZipFileEntry *>(zip.directory()->entry(QStringLiteral("logo.png")));
+    QVERIFY(entry);
+    QCOMPARE(entry->size(), 3589);
+    QCOMPARE(entry->compressedSize(), 3594);
+    QCOMPARE(entry->position(), 8943);
+}
+
 void KArchiveTest::testRcc()
 {
     const QString rccFile = QFINDTESTDATA("runtime_resource.rcc"); // was copied from qtbase/tests/auto/corelib/io/qresourceengine
@@ -1506,7 +1537,8 @@ void KArchiveTest::test7ZipMaxLength()
 
     // Generate long filenames of each possible length bigger than 98...
     for (int i = 98; i < 514; i++) {
-        QString str, num;
+        QString str;
+        QString num;
         str.fill('a', i - 10);
         num.setNum(i);
         num = num.rightJustified(10, '0');
@@ -1537,3 +1569,5 @@ void KArchiveTest::test7ZipMaxLength()
     QFile::remove(fileName);
 }
 #endif
+
+#include "moc_karchivetest.cpp"
